==> 0.0.2.tar.gz: lib/bean/yf_ads_init_sdk_android_bean.dart <==


import 'package:yf_ads/bean/yf_ads_init_sdk_base_bean.dart';

class YFAdsInitSDKAndroidBean extends YFAdsInitSDKBaseBean {
  final String? appId;
  final String? appKey;

  final String? ext1;
  final String? ext2;
  final String? ext3;
  final String? ext4;
  final String? ext5;
  final String? ext6;
  final String? ext7;
  final String? ext8;

  final String? channelId;
  final bool? permissionLocation;
  final String? firstActiveTime;

  final List<double>? location;

  final bool? permissionPhoneState;
  final bool? permissionWifiState;
  final bool? permissionWriteExternal;
  final bool? permissionOaid;
  final bool? permissionAndroidId;
  final String? imei;
  final String? oaid;
  final bool? permissionAppList;
  final bool? enableLog;

  const YFAdsInitSDKAndroidBean(
      {required this.appId,
      required this.appKey,
      this.channelId = "",
      this.ext1 = "",
      this.ext2 = "",
      this.ext3 = "",
      this.ext4 = "",
      this.ext5 = "",
      this.ext6 = "",
      this.ext7 = "",
      this.ext8 = "",
      this.permissionLocation = true,
      this.firstActiveTime = "",
      this.location,
      this.permissionPhoneState = true,
      this.permissionWifiState = true,
      this.permissionWriteExternal = true,
      this.permissionOaid = true,
      this.permissionAndroidId = true,
      this.imei = "",
      this.oaid = "",
      this.enableLog = false,
      this.permissionAppList = true})
      : super();

  YFAdsInitSDKAndroidBean.fromJson(Map<String, dynamic> json)
      : appId = json['appId'],
        appKey = json['appKey'],
        channelId = json['channelId'],
        ext1 = json['ext1'],
        ext2 = json['ext2'],
        ext3 = json['ext3'],
        ext4 = json['ext4'],
        ext5 = json['ext5'],
        ext6 = json['ext6'],
        ext7 = json['ext7'],
        ext8 = json['ext8'],
        permissionLocation = json['permissionLocation'],
        location = json['location'],
        permissionPhoneState = json['permissionPhoneState'],
        permissionWifiState = json['permissionWifiState'],
        permissionWriteExternal = json['permissionWriteExternal'],
        permissionOaid = json['permissionOaid'],
        permissionAndroidId = json['permissionAndroidId'],
        imei = json['imei'],
        oaid = json['oaid'],
        permissionAppList = json['permissionAppList'],
        firstActiveTime = json['firstActiveTime'],
        enableLog = json['enableLog'];

  Map<String, dynamic> toJson() => {
        'appId': appId,
        'appKey': appKey,
        'channelId': channelId,
        'ext1': ext1,
        'ext2': ext2,
        'ext3': ext3,
        'ext4': ext4,
        'ext5': ext5,
        'ext6': ext6,
        'ext7': ext7,
        'ext8': ext8,
        'permissionLocation': permissionLocation,
        'location': location,
        'permissionPhoneState': permissionPhoneState,
        'permissionWifiState': permissionWifiState,
        'permissionWriteExternal': permissionWriteExternal,
        'permissionOaid': permissionOaid,
        'permissionAndroidId': permissionAndroidId,
        'imei': imei,
        'oaid': oaid,
        'permissionAppList': permissionAppList,
        'firstActiveTime': firstActiveTime,
        'enableLog': enableLog
      };
}

==> 0.0.10.tar.gz: lib/bean/yf_ads_init_sdk_android_bean.dart <==


import 'package:yf_ads/bean/yf_ads_init_sdk_base_bean.dart';

class YFAdsInitSDKAndroidBean extends YFAdsInitSDKBaseBean {
  final String? appId;
  final String? appKey;

  final String? ext1;
  final String? ext2;
  final String? ext3;
  final String? ext4;
  final String? ext5;
  final String? ext6;
  final String? ext7;
  final String? ext8;

  final String? channelId;
  final bool? permissionLocation;
  final String? firstActiveTime;

  final List<double>? location;

  final bool? permissionPhoneState;
  final bool? permissionWifiState;
  final bool? permissionWriteExternal;
  final bool? permissionOaid;
  final bool? permissionAndroidId;
  final String? imei;
  final String? oaid;
  final bool? permissionAppList;
  final bool? enableLog;
  final bool? envTest;

  const YFAdsInitSDKAndroidBean(
      {required this.appId,
      required this.appKey,
      this.channelId = "",
      this.ext1 = "",
      this.ext2 = "",
      this.ext3 = "",
      this.ext4 = "",
      this.ext5 = "",
      this.ext6 = "",
      this.ext7 = "",
      this.ext8 = "",
      this.permissionLocation = true,
      this.firstActiveTime = "",
      this.location,
      this.permissionPhoneState = true,
      this.permissionWifiState = true,
      this.permissionWriteExternal = true,
      this.permissionOaid = true,
      this.permissionAndroidId = true,
      this.imei = "",
      this.oaid = "",
      this.enableLog = false,
      this.envTest = false,
      this.permissionAppList = true})
      : super();

  YFAdsInitSDKAndroidBean.fromJson(Map<String, dynamic> json)
      : appId = json['appId'],
        appKey = json['appKey'],
        channelId = json['channelId'],
        ext1 = json['ext1'],
        ext2 = json['ext2'],
        ext3 = json['ext3'],
        ext4 = json['ext4'],
        ext5 = json['ext5'],
        ext6 = json['ext6'],
        ext7 = json['ext7'],
        ext8 = json['ext8'],
        permissionLocation = json['permissionLocation'],
        location = json['location'],
        permissionPhoneState = json['permissionPhoneState'],
        permissionWifiState = json['permissionWifiState'],
        permissionWriteExternal = json['permissionWriteExternal'],
        permissionOaid = json['permissionOaid'],
        permissionAndroidId = json['permissionAndroidId'],
        imei = json['imei'],
        oaid = json['oaid'],
        permissionAppList = json['permissionAppList'],
        firstActiveTime = json['firstActiveTime'],
        enableLog = json['enableLog'],
        envTest = json['envTest'];

  Map<String, dynamic> toJson() => {
        'appId': appId,
        'appKey': appKey,
        'channelId': channelId,
        'ext1': ext1,
        'ext2': ext2,
        'ext3': ext3,
        'ext4': ext4,
        'ext5': ext5,
        'ext6': ext6,
        'ext7': ext7,
        'ext8': ext8,
        'permissionLocation': permissionLocation,
        'location': location,
        'permissionPhoneState': permissionPhoneState,
        'permissionWifiState': permissionWifiState,
        'permissionWriteExternal': permissionWriteExternal,
        'permissionOaid': permissionOaid,
        'permissionAndroidId': permissionAndroidId,
        'imei': imei,
        'oaid': oaid,
        'permissionAppList': permissionAppList,
        'firstActiveTime': firstActiveTime,
        'enableLog': enableLog,
        'envTest': envTest
      };
}
